AccessibilityEvent class

Constructors

AccessibilityEvent({String? mapId, String? nodeId, NodeAction? actionType, DateTime? eventTime, String? packageName, EventType? eventType, String? text, ContentChangeTypes? contentChangeTypes, int? movementGranularity, WindowType? windowType, bool? isActive, bool? isFocused, bool? isClickable, bool? isScrollable, bool? isFocusable, bool? isCheckable, bool? isLongClickable, bool? isEditable, bool? isPip, ScreenBounds? screenBounds, List<NodeAction>? actions})
AccessibilityEvent.fromMap(Map map)

Properties

actions ↔ List<NodeAction>?
Get the node childrens available actions https://developer.android.com/reference/android/view/accessibility/AccessibilityNodeInfo#getViewIdResourceName()
getter/setter pair
actionType ↔ NodeAction?
The performed action that triggered this event https://developer.android.com/reference/android/view/accessibility/AccessibilityEvent#getAction()
getter/setter pair
contentChangeTypes ↔ ContentChangeTypes?
the bit mask of change types signaled by a TYPE_WINDOW_CONTENT_CHANGED event or TYPE_WINDOW_STATE_CHANGED. A single event may represent multiple change types https://developer.android.com/reference/android/view/accessibility/AccessibilityEvent#getContentChangeTypes()
getter/setter pair
eventTime ↔ DateTime?
the time in which this event was sent. https://developer.android.com/reference/android/view/accessibility/AccessibilityEvent#TYPE_WINDOW_CONTENT_CHANGED
getter/setter pair
eventType ↔ EventType?
the event type. https://developer.android.com/reference/android/view/accessibility/AccessibilityEvent#getEventType()
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isActive ↔ bool?
check if this window is active. An active window is the one the user is currently touching or the window has input focus and the user is not touching any window. https://developer.android.com/reference/android/view/accessibility/AccessibilityWindowInfo#isActive()
getter/setter pair
isCheckable ↔ bool?
check if this node is checkable.
getter/setter pair
isClickable ↔ bool?
check if this node is clickable.
getter/setter pair
isEditable ↔ bool?
check if this node is long editable.
getter/setter pair
isFocusable ↔ bool?
check if this node is focusable.
getter/setter pair
isFocused ↔ bool?
check if this window has input focus. https://developer.android.com/reference/android/view/accessibility/AccessibilityWindowInfo#isFocused()
getter/setter pair
isLongClickable ↔ bool?
check if this node is long clickable.
getter/setter pair
isPip ↔ bool?
Check if the window is in picture-in-picture mode. https://developer.android.com/reference/android/view/accessibility/AccessibilityWindowInfo#isInPictureInPictureMode()
getter/setter pair
isScrollable ↔ bool?
check if this node is scrollable.
getter/setter pair
mapId ↔ String?
Unique identifier generated by the plugin
getter/setter pair
movementGranularity ↔ int?
the movement granularity that was traversed https://developer.android.com/reference/android/view/accessibility/AccessibilityEvent#getMovementGranularity()
getter/setter pair
nodeId ↔ String?
Gets the fully qualified resource name of the source view's id. https://developer.android.com/reference/android/view/accessibility/AccessibilityNodeInfo#getViewIdResourceName()
getter/setter pair
packageName ↔ String?
the package name of the source https://developer.android.com/reference/android/view/accessibility/AccessibilityEvent#getPackageName()
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
screenBounds ↔ ScreenBounds?
Gets the node bounds in screen coordinates. https://developer.android.com/reference/android/view/accessibility/AccessibilityNodeInfo#getBoundsInScreen(android.graphics.Rect)
getter/setter pair
subNodes ↔ List<AccessibilityEvent>?
Get the node childrens and sub childrens info https://developer.android.com/reference/android/view/accessibility/AccessibilityNodeInfo#getViewIdResourceName()
getter/setter pair
text ↔ String?
Gets the text of this node. https://developer.android.com/reference/android/view/accessibility/AccessibilityNodeInfo#getText()
getter/setter pair
windowType ↔ WindowType?
the type of the window https://developer.android.com/reference/android/view/accessibility/AccessibilityWindowInfo#getType()
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited