ScreenBounds class

Constructors

ScreenBounds({int? right, int? top, int? left, int? bottom, int? width, int? height})
ScreenBounds.fromMap(Map json)

Properties

bottom ↔ int?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ int?
getter/setter pair
left ↔ int?
getter/setter pair
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ int?
getter/setter pair
width ↔ int?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited