OverlayConfig class

OverlayConfig class This class is used to configure the overlay window

Constructors

OverlayConfig({bool clickableThrough = false, int width = -1, int height = -1, OverlayGravity gravity = OverlayGravity.top})
const

Properties

clickableThrough → bool
Whether the overlay window is clickable through If true, the overlay window will not intercept touch events
final
gravity → OverlayGravity
The gravity of the overlay window This determines where the overlay window will be displayed on the screen The default value is OverlayGravity.top
final
hashCode → int
The hash code for this object.
no setterinherited
height → int
The height of the overlay window If -1, the height will be set to the height of the screen
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → int
The width of the overlay window If -1, the width will be set to the width of the screen
final

Methods

copyWith({bool? clickableThrough, int? width, int? height, OverlayGravity? gravity}) → OverlayConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited