GestureDescription class
Describes a compound gesture made of one or more GestureStrokes.
Maps to Android's android.accessibilityservice.GestureDescription.
Requires Android 7.0 (API 24) or higher.
Example — swipe up:
GestureDescription(
strokes: [
GestureStroke(
path: [GesturePoint(500, 1500), GesturePoint(500, 300)],
startTime: 0,
duration: 400,
),
],
)
Constructors
-
GestureDescription({required List<
GestureStroke> strokes}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
strokes
→ List<
GestureStroke> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → List< Map< String, dynamic> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited