GestureStroke class
One continuous touch stroke within a GestureDescription.
path — ordered list of points that define the stroke. startTime — milliseconds after the gesture starts before this stroke begins (default 0). duration — how long the stroke lasts in milliseconds (default 100).
Constructors
-
GestureStroke({required List<
GesturePoint> path, int startTime = 0, int duration = 100}) -
const
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited